@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2011 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2013 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -31,7 +31,7 @@
       DO L=-LM,-1
         DO M=-MM,MM
           DO N=-NM,NM
-            K=SQRT(1D0*(L*L+M*M+N*N))+0.5D0
+            K=INT(SQRT(1D0*(L*L+M*M+N*N))+0.5D0)
             IF(K.LE.KMAX) THEN
               ES(K)=ES(K)+((L*L+M*M)*Z(N,M,L,1)*Z(N,M,L,1)
      &          +(L*L+N*N)*Z(N,M,L,2)*Z(N,M,L,2)
@@ -43,7 +43,7 @@
       DO L=1,LM
         DO M=-MM,MM
           DO N=-NM,NM
-            K=SQRT(1D0*(L*L+M*M+N*N))+0.5D0
+            K=INT(SQRT(1D0*(L*L+M*M+N*N))+0.5D0)
             IF(K.LE.KMAX) THEN
               ES(K)=ES(K)+((L*L+M*M)*Z(N,M,L,1)*Z(N,M,L,1)
      &          +(L*L+N*N)*Z(N,M,L,2)*Z(N,M,L,2)
@@ -56,7 +56,7 @@
       L=0
       DO M=-MM,-1
         DO N=-NM,NM
-          K=SQRT(1D0*(M*M+N*N))+0.5D0
+          K=INT(SQRT(1D0*(M*M+N*N))+0.5D0)
           IF(K.LE.KMAX) THEN
             ES(K)=ES(K)+(M*M*Z(N,M,L,2)*Z(N,M,L,2)
      &        +(M*M+N*N)*Z(N,M,L,1)*Z(N,M,L,1))
@@ -66,7 +66,7 @@
       END DO
       DO M=1,MM
         DO N=-NM,NM
-          K=SQRT(1D0*(M*M+N*N))+0.5D0
+          K=INT(SQRT(1D0*(M*M+N*N))+0.5D0)
           IF(K.LE.KMAX) THEN
             ES(K)=ES(K)+(M*M*Z(N,M,L,2)*Z(N,M,L,2)
      &        +(M*M+N*N)*Z(N,M,L,1)*Z(N,M,L,1))
