@@ -1,6 +1,6 @@
 ************************************************************************
 * ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-* Copyright (C) 1998--2010 Keiichi Ishioka <ishioka@gfd-dennou.org>
+* Copyright (C) 1998--2013 Keiichi Ishioka <ishioka@gfd-dennou.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -28,7 +28,7 @@
       LM=(MM+1)*(MM+1)
 
       DO L=1,LM
-        N=SQRT(1D0*(L-1))
+        N=INT(SQRT(1D0*(L-1)))
         M=L-N*(N+1)-1
         IRM(L,1)=-M+1+N*(N+1)
         IRM(L,2)=M
